@@ -87,7 +87,7 @@ class FormController(Controller):
         Override this method to return a different response in case of an invalid form.
         The default implementation should be enough for most cases.
         """
-        return self.render(cls.template, context=self.context, status_code=400)
+        return self.render(self.template, context=self.context, status_code=400)
 
     def get_context(self):
         """
